@@ -24,8 +24,9 @@ def process(ids: tuple[str], offset: int):
     user = tk.get_action("get_site_user")({"ignore_auth": True}, {})
     resources = _get_resources(ids)
     with click.progressbar(resources, length=resources.count()) as bar:
-        for step, res in enumerate(bar):
-            if step < offset:
+        for res in bar:
+            bar.label = bar.pos
+            if bar.pos < offset:
                 continue
             utils.create_thumbnail({"user": user["name"]}, {
                 "id": res.id,
